This directory contains "simple" rules that are used in the pipelines. There is
no config file provided but may be required. The unique config file used in
**Sequana** can be found in the pipelines directory. One can also initialise a
pipeline locally in a shell::

    sequana --init quality

This will download the quality pipeline and the config file named **config.yaml**
